# The lines from here to the =cut are part of Perl's
# internal documentation system.  If you want 
# view the documentation use the command:
#
#	pod2text <script>
#
=pod

=head1 NAME

make.pl - Split Makefile macro definitions into comment and macro

=head1 SYNOPSIS

    perl make.pl < {in-file} 

=head1 DESCRIPTION

The I<make.pl> reads a Makefile and reports on the comments and macro definitions
on each line.  Comments begin with "#" and go to the end of the line.

Macros are of the form:

    NAME=VALUE
    NAME="String value"

Note: Strings can contain B<#> and B<\">.

Actually this is a demonstration of regular expressions in the extreme case.

=head1 AUTHOR

Steve Oualline, E<lt>oualline@www.oualline.comE<gt>.

=head1 COPYRIGHT

Copyright 2002 Steve Oualline.
This program is distributed under the GPL.  

=cut
use strict;
use warnings;

my $line;
while ($line = <STDIN>) {
    # No \n because it's already in $line
    print "Line: $line";        

    if ($line =~ /^\s*#/) {
        next;
    }    
    #                +--------------------------------- Match start of line
    #                |    +++++------------------------ Match all except # or "
    #                |    |||||+----------------------- Repeat 0 or more times (*)
    #                |    ||||||
    #                |    ||||||+---------------------- Match either pattern (|)
    #                |    ||||||#
    #                |    ||||||#+--------------------- Match "
    #                |    ||||||#|+-------------------- Any character (.)
    #                |    ||||||#||+------------------- Repeat 0 or more times (*)
    #                |    ||||||#|||+------------------ As little as possible (?)
    #                |    ||||||#||||+++++------------- Lookback conditional
    #                |    ||||||#||||^||||              Must not be preceded by:
    #                |    ||||||#||||^||||++----------- The character \
    #                |    ||||||#||||^|||||^+---------- Match "
    #                |    ||||||#||||^|||||^|
    #                | +++||||||#||||^|||||^|+--------- Group the following but 
    #                | |||||||||#||||^|||||^||          put do not put into $n ( (?: )
    #                | |||||||||#||||^|||||^||+-------- Repeated 0 or more times (*)
    #                |+|||||||||#||||^|||||^|||+------- Put the enclosed in $1
    #                |^|||||||||#||||^|||||^|||^ 
    #                |^|||||||||#||||^|||||^|||^ +----- The character hash (#)
    #                |^|||||||||#||||^|||||^|||^ |+---- Any character (.)
    #                |^|||||||||#||||^|||||^|||^ ||+--- Repeated 0 or more times (*)
    #                |^|||||||||#||||^|||||^|||^+|||+-- Put the enclosed in $3
    elsif ($line =~ /^((?:[^#"]*|".*?(?<!\\)")*)(#.*)/) {
        print "Type: Command with Comment\n";
        print "Command: $1\n";
        print "Comment: $2\n";
    } else {
        print "Type: Command only\n";
    }
    print "\n";
}
