# The lines from here to the =cut are part of Perl's
# internal documentation system.  If you want 
# view the documentation use the command:
#
#	pod2text <script>
#
=pod

=head1 NAME

date.pl - Read a file containing dates and prints out a list of years

=head1 SYNOPSIS

    perl date.pl 

=head1 DESCRIPTION

The I<date.pl> demonstrates how to read in complex data (in this
case dates), parse it, and store it in a hash.  

The results are then processed to come up with a list of the years
present in the list.

The input is contained in the file I<dates.txt>.

=head1 EXAMPLES

Sample run:

	perl date.pl
	01
	45
	56
	66
	87
	98

=head1 AUTHOR

Steve Oualline, E<lt>oualline@www.oualline.comE<gt>.

=head1 COPYRIGHT

Copyright 2002 Steve Oualline.
This program is distributed under the GPL.  

=cut
use strict;
use warnings;

open IN_FILE, "<dates.txt" or die("Could not open dates.txt");

my @date_array = ();	# The dates we have read in

my $line;	# Line from the input file

while ($line = <IN_FILE>) {
    chomp($line);
    
    # Date is of the form mm/dd/yyyy (WARNING: This format is USA specific)
    my @date_parts = split /\//, $line;
    
    if ($#date_parts != 2) {
        print STDERR "Bad input line $line";
    }
    my %date_hash = ( 
        month => $date_parts[0],
        day => $date_parts[1],
        year => $date_parts[2]);
    push (@date_array, {%date_hash});
}
close IN_FILE;
# Now let's figure out which years are present
my %year_hash;

foreach my $cur_date (@date_array) {
    $year_hash{$cur_date->{year}} = 1;
}
# Print out the years 
foreach my $cur_year (sort keys %year_hash)
{
    print "$cur_year\n";
}
